@@ -76,7 +76,8 @@ void ArrayListSetDeallocationFunction(ArrayList * list,  void (*elem_deallocator
 void ArrayListSort(ArrayList * list, int compare_L_minus_R(void * L_elem, void * R_elem, ArrayList * me));
 
 // A simple comparison function if you want to sort unsigned long long ints.
-int ArrayListLLUComparison(void * L_elem, void * R_elem);
+int ArrayListLLUComparison(void * L_elem, void * R_elem, ArrayList * me);
+int ArrayListStringComparison(void * L_elem, void * R_elem, ArrayList * me);
 
 // This function returns the index of the value in the list that is the minumum value greater than "value_less_than_dent".
 // The elements in the list are all zero-based unsigned long long ints. The list must be sorted (small -> large) before calling this function.
@@ -120,6 +121,11 @@ HashTable * StringTableCreate(srInt_64 numOfBuckets);
 HashTable * StringTableReverse(HashTable * ori);
 HashTable *HashTableCreate(srInt_64 numOfBuckets);
 
+// increase the value of key by 1.
+// the value must be a NULL+n number.
+// it returns the new value for the key.
+srInt_64 HashTableInc(HashTable *tab, void *key);
+
 /*--------------------------------------------------------------------------*\
  *  NAME:
  *      HashTableDestroy() - destroys an existing HashTable
