@@ -63,8 +63,6 @@
 #define RUN_ALIGN 		0
 #define RUN_FINAL 		1
 
-
-
 #define MAX_THREADS 40
 #define FC_MAX_THREADS 64
 #define MAX_EVENTS_IN_READ 8
@@ -83,7 +81,8 @@
 #define EXON_LONG_READ_LENGTH 160 
 #define EXON_MAX_CIGAR_LEN 256 
 #define FC_CIGAR_PARSER_ITEMS 11 
-#define FC_LONG_READ_RECORD_HARDLIMIT (8*1024*1024)
+#define FC_LONG_READ_RECORD_HARDLIMIT (64*1024-1)
+#define FC_UNSAFE_BLOCK_SIZE 15000
 
 #define MAX_INDEL_SECTIONS 7
 //#define XBIG_MARGIN_RECORD_SIZE 24 
